/**
 * ab_two_gis_maps package for Concrete5
 * Copyright Copyright 2017-2019, Alex Borisov
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @author Alex Borisov <linuxoidoz@gmail.com>
 * @package Concrete\Package\ab_two_gis_maps
 */

$(document).ready(function(e) {
    if(CCM_EDIT_MODE){
        return;
    }
    
    DG.then(function() {
        $.each($('.ab-two-gis-map[data-jq]'), function(index, element) {
            var jq_data = $.parseJSON($(element).attr('data-jq'));
            InitTwoGisMap(element, jq_data);
        });
    });

    function InitTwoGisMap(element, jq_data) {
        var myTwoGisBalloon = '<div class="my-balloon">';
            if (jq_data.show_picture) {
                myTwoGisBalloon += '<div class="left">';
                myTwoGisBalloon += '<img src="' + jq_data.picture + '" />';
                myTwoGisBalloon += '</div>';
            }
            myTwoGisBalloon += '<div class="right">'; 
            myTwoGisBalloon += '<h3>' + jq_data.name + '</h3>';
            myTwoGisBalloon += jq_data.show_address ? ('<strong>' + jq_data.t_address + '</strong> ' + jq_data.address + '<br />') : '';
            myTwoGisBalloon += jq_data.show_tel ? ('<strong>' + jq_data.t_tel + '</strong> ' + jq_data.tel + '<br />') : '';
            myTwoGisBalloon += jq_data.show_email ? ('<strong>' + jq_data.t_email + '</strong> <a href="mailto:' + jq_data.email + '">' + jq_data.email + '</a>') : '';
            myTwoGisBalloon += '</div>';
            myTwoGisBalloon += '</div>';
            
        var myTwoGisHint = '<div class="my-hint">';
        myTwoGisHint += '<b>' + jq_data.name + '</b><br />';
        myTwoGisHint += jq_data.address + '<br />';
        myTwoGisHint += jq_data.tel + '<br />';
        myTwoGisHint += jq_data.email;
        myTwoGisHint += '</div>';
            
        var myTwoGisMap, myTwoGisPopUp, myTwoGisPlacemark;

        myTwoGisMap = DG.map(element, {
            'center': [jq_data.latitude, jq_data.longitude],
            'zoom': jq_data.zoom ? jq_data.zoom : 12,
            'scrollWheelZoom' : jq_data.lock_wheel,
        });
        myTwoGisMap.setLang(jq_data.t_lang);

        myTwoGisPopUp = DG.popup();
        myTwoGisPopUp.setLatLng([jq_data.latitude, jq_data.longitude]);
        myTwoGisPopUp.setContent(myTwoGisBalloon);
        
        myTwoGisPlacemark = DG.marker([jq_data.latitude, jq_data.longitude]).addTo(myTwoGisMap);
        myTwoGisPlacemark.bindPopup(myTwoGisPopUp);
        myTwoGisPlacemark.bindLabel(myTwoGisHint, {
            static: false,
            className: 'ab-two-gis-maps-hint',
        });
    };
});
